aboutsummaryrefslogtreecommitdiff
path: root/src/addrman.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/addrman.h')
-rw-r--r--src/addrman.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/addrman.h b/src/addrman.h
index 374996e501..c8e31fe283 100644
--- a/src/addrman.h
+++ b/src/addrman.h
@@ -146,11 +146,12 @@ public:
/**
* Choose an address to connect to.
*
* @param[in] new_only Whether to only select addresses from the new table.
* @return CAddress The record for the selected peer.
* seconds The last time we attempted to connect to that peer.
*/
- std::pair<CAddress, NodeSeconds> Select(bool new_only = false) const;
+ std::pair<CAddress, NodeSeconds> Select(bool new_only = false, std::optional<Network> network = std::nullopt) const;
/**
* Return all or many randomly selected addresses, optionally by network.
@@ -146,11 +146,12 @@ public:
* Choose an address to connect to.
*
- * @param[in] new_only Whether to only select addresses from the new table.
+ * @param[in] new_only Whether to only select addresses from the new table.
+ * @param[in] network Select only addresses of this network (nullopt = all)
* @return CAddress The record for the selected peer.
* seconds The last time we attempted to connect to that peer.